**P**\hotonic & **I**\ntegrated **EL**\ectronic
===============================================
Co-simulation system design tools interfaced with open-source design software like GDSFactory and OpenROAD.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   examples
   sections/environment/index
   sections/microservices/index
   sections/codesign/index
   sections/components/index
   sections/models/index
   contributing
   sections/about/index


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
